/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CMIServerConfigurator.java 1823 2008-06-03 18:03:18Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.server.component;

import java.net.URL;

import org.ow2.cmi.controller.server.ServerClusterViewManager;
import org.ow2.cmi.controller.server.ServerClusterViewManagerException;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.xmlconfig.XMLConfiguration;
import org.ow2.util.xmlconfig.XMLConfigurationException;
import org.ow2.util.xmlconfig.properties.SystemPropertyResolver;


/**
 * Allows to configure a CMI server with an XML configuration file.
 * @author Loris Bouzonnet (greatly inspired from org.ow2.easybeans.server.EmbeddedConfigurator by Florent Benoit)
 */
public final class CMIServerConfigurator {

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(CMIServerConfigurator.class);


    /**
     * Utility class, no public constructor.
     */
    private CMIServerConfigurator() {

    }

    /**
     * Configure the given CMI server with the given XML configuration file URL.
     * @param serverClusterViewManager the CMI server to configure.
     * @param xmlConfigurationURL the URL to the xml configuration file.
     * @return the configured CMI server instance.
     * @throws ServerClusterViewManagerException if the configuration fails.
     */
    public static ServerClusterViewManager init(final ServerClusterViewManager serverClusterViewManager, final URL xmlConfigurationURL)
    throws ServerClusterViewManagerException {
        configure(serverClusterViewManager, xmlConfigurationURL);
        return serverClusterViewManager;
    }

    /**
     * Configure the given CMI server with the xml configuration file.
     * @param serverClusterViewManager the CMI server to configure.
     * @param xmlConfigurationURL the URL to the xml configuration file.
     * @throws ServerClusterViewManagerException if the configuration fails.
     */
    private static void configure(final ServerClusterViewManager serverClusterViewManager, final URL xmlConfigurationURL)
    throws ServerClusterViewManagerException {
        long tStart = System.currentTimeMillis();
        logger.debug("Starting configuration of CMI server");
        XMLConfiguration xmlConfiguration = new XMLConfiguration(xmlConfigurationURL, "cmi-server-mapping.xml");

        // Resolve properties as system properties
        xmlConfiguration.setPropertyResolver(new SystemPropertyResolver());

        try {
            xmlConfiguration.configure(serverClusterViewManager);
        } catch (XMLConfigurationException e) {
            throw new ServerClusterViewManagerException("Cannot configure the CMI server", e);
        }
        if (logger.isInfoEnabled()) {
            logger.debug("Configuration done in : " + (System.currentTimeMillis() - tStart) + " ms");
        }
    }

}
