/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: carol@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: IdentityFilter.java 1798 2008-05-19 12:13:01Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.server.filter;

import java.io.Serializable;
import java.util.Iterator;
import java.util.Set;


/**
 * A convenient abstract filter that only accepts the same quality.
 * @author Loris Bouzonnet
 */
public abstract class IdentityFilter implements IFilter, Serializable {

    /**
     * A quality.
     */
    private final Object quality;

    /**
     * Construct a filter for a given quality
     * @param quality a required quality to apply this filter
     */
    protected IdentityFilter(final Object quality) {
        this.quality = quality;
    }

    public boolean accept(final Set<Object> qualities) {
        boolean accepted = false;
        Iterator<?> iterQuality = qualities.iterator();
        while(!accepted && iterQuality.hasNext()) {
            if(quality.equals(iterQuality.next())) {
                accepted = true;
            }
        }
        return accepted;
    }

}
